@@ -100,8 +100,8 @@ void JavaClassDeclarationBlock::updateContent ()
     int i = 0;
     if (nrof_superclasses >0)
         startText.append(QStringLiteral(" extends "));
-    foreach (UMLClassifier* concept, superclasses) {
-        startText.append(parentDoc->cleanName(concept->name()));
+    foreach (UMLClassifier* classifier, superclasses) {
+        startText.append(parentDoc->cleanName(classifier->name()));
         if(i != (nrof_superclasses-1))
             startText.append(QStringLiteral(", "));
         i++;
@@ -117,8 +117,8 @@ void JavaClassDeclarationBlock::updateContent ()
         else
             startText.append(QStringLiteral(" implements "));
     }
-    foreach (UMLClassifier* concept, superinterfaces) {
-        startText.append(parentDoc->cleanName(concept->name()));
+    foreach (UMLClassifier* classifier, superinterfaces) {
+        startText.append(parentDoc->cleanName(classifier->name()));
         if(i != (nrof_superinterfaces-1))
             startText.append(QStringLiteral(", "));
         i++;
