@@ -12,7 +12,7 @@
 // kde includes
 #include <KLocalizedString>
 #include <ktextedit.h>
-#include <klineedit.h>
+#include <QLineEdit>
 
 // qt includes
 #include <QHBoxLayout>
@@ -52,7 +52,7 @@ void UMLCheckConstraintDialog::setupDialog()
     m_pNameL = new QLabel(i18nc("name label", "Name"), this);
     nameLayout->addWidget(m_pNameL);
     // name lineEdit
-    m_pNameLE = new KLineEdit(this);
+    m_pNameLE = new QLineEdit(this);
     nameLayout->addWidget(m_pNameLE);
 
     QVBoxLayout* checkConditionLayout = new QVBoxLayout();
